@@ -219,6 +219,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			name:    "dest-dir",
 			dirname: c.DestDirAbsPath,
 		},
+		hardlinkCheck{},
 		umaskCheck{},
 		&binaryCheck{
 			name:       "cd-command",
@@ -413,15 +414,6 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionArgs: []string{"version"},
 			versionRx:   regexp.MustCompile(`^Vault\s+v(\d+\.\d+\.\d+)`),
 		},
-		&binaryCheck{
-			name:        "vlt-command",
-			binaryName:  c.HCPVaultSecrets.Command,
-			ifNotSet:    checkResultWarning,
-			ifNotExist:  checkResultInfo,
-			versionArgs: []string{"version"},
-			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
-			minVersion:  &vltMinVersion,
-		},
 		&binaryCheck{
 			name:       "secret-command",
 			binaryName: c.Secret.Command,
