@@ -13,7 +13,7 @@ import (
 	"github.com/gopasspw/gopass/pkg/gopass"
 	"github.com/gopasspw/gopass/pkg/gopass/api"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 type gopassMode string
@@ -109,7 +109,7 @@ func (c *Config) builtinGopassClient() (*api.Gopass, error) {
 		}
 		return c.Gopass.passwordCache[filename], nil
 	})
-	c.Gopass.ctx = ctx
+	c.Gopass.ctx = ctx //nolint:fatcontext
 	c.Gopass.client, c.Gopass.clientErr = api.New(c.Gopass.ctx)
 	return c.Gopass.client, c.Gopass.clientErr
 }
