@@ -3,7 +3,6 @@
 package cmd
 
 import (
-	"bufio"
 	"bytes"
 	"context"
 	"crypto/sha256"
@@ -38,7 +37,7 @@ const (
 )
 
 var (
-	checksumRx                  = regexp.MustCompile(`\A([0-9a-f]{64})\s+(\S+)\z`)
+	checksumRx                  = regexp.MustCompile(`\A([0-9a-f]{64})\s+(\S+)\n\z`)
 	errUnsupportedUpgradeMethod = errors.New("unsupported upgrade method")
 )
 
@@ -184,15 +183,14 @@ func (c *Config) getChecksums(ctx context.Context, rr *github.RepositoryRelease)
 	}
 
 	checksums := make(map[string][]byte)
-	s := bufio.NewScanner(bytes.NewReader(data))
-	for s.Scan() {
-		m := checksumRx.FindStringSubmatch(s.Text())
+	for line := range bytes.Lines(data) {
+		m := checksumRx.FindSubmatch(line)
 		if m == nil {
-			return nil, fmt.Errorf("%q: cannot parse checksum", s.Text())
+			return nil, fmt.Errorf("%q: cannot parse checksum", line)
 		}
-		checksums[m[2]], _ = hex.DecodeString(m[1])
+		checksums[string(m[2])], _ = hex.DecodeString(string(m[1]))
 	}
-	return checksums, s.Err()
+	return checksums, nil
 }
 
 func (c *Config) downloadURL(ctx context.Context, url string) ([]byte, error) {
@@ -233,9 +231,14 @@ func (c *Config) replaceExecutable(
 	switch {
 	case runtime.GOOS == "linux" && runtime.GOARCH == "amd64":
 		archiveFormat = chezmoi.ArchiveFormatTarGz
+		// Determine the libc to use. If the executable is dynamically linked
+		// (as indicated by ldd running and returning without error), then use
+		// glibc, otherwise use musl.
 		var libc string
-		if libc, err = getLibc(); err != nil {
-			return err
+		if err := exec.Command("ldd", executableFilenameAbsPath.String()).Run(); err == nil {
+			libc = "glibc"
+		} else {
+			libc = "musl"
 		}
 		archiveName = fmt.Sprintf("chezmoi_%s_%s-%s_%s.tar.gz", releaseVersion, runtime.GOOS, libc, runtime.GOARCH)
 	case runtime.GOOS == "linux" && runtime.GOARCH == "386":
