@@ -6,12 +6,12 @@ import (
 
 	"golang.org/x/sys/windows/registry"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 const defaultEditor = "notepad.exe"
 
-var defaultInterpreters = map[string]*chezmoi.Interpreter{
+var defaultInterpreters = map[string]chezmoi.Interpreter{
 	"bat": {},
 	"cmd": {},
 	"com": {},
